@@ -232,7 +232,6 @@ timed_wait_callback (gpointer callback_data)
 	gtk_window_set_default_size (GTK_WINDOW (dialog),
 				     TIMED_WAIT_MINIMUM_DIALOG_WIDTH,
 				     -1);
-	gtk_window_set_wmclass (GTK_WINDOW (dialog), "dialog", "Eel");
 	add_label_to_dialog (dialog, wait->wait_message);
 	wait->dialog_creation_time = eel_get_system_time ();
 	gtk_widget_show_all (GTK_WIDGET (dialog));
@@ -366,7 +365,6 @@ eel_run_simple_dialog (GtkWidget *parent, gboolean ignore_close_box,
 	}
 	va_end (button_title_args);
 	
-	gtk_window_set_wmclass (GTK_WINDOW (dialog), "dialog", "Eel");
 
 	/* Title it if asked to. */
 	add_label_to_dialog (GTK_DIALOG (dialog), text);
@@ -396,7 +394,6 @@ create_message_dialog (const char *message,
 
 	box = gtk_message_dialog_new (parent, 0, type, buttons_type, "%s", message);
 	gtk_window_set_title (GTK_WINDOW (box), dialog_title);
-	gtk_window_set_wmclass (GTK_WINDOW (box), "stock_dialog", "Eel");
 	
 	return GTK_DIALOG (box);
 }
